slepc-3.18.0 2022-10-01
Report Typos and Errors

# FNType

String with the name of the mathematical function.

### Synopsis

    typedef const char* FNType;
    #define FNCOMBINE  "combine"
    #define FNRATIONAL "rational"
    #define FNEXP      "exp"
    #define FNLOG      "log"
    #define FNPHI      "phi"
    #define FNSQRT     "sqrt"
    #define FNINVSQRT  "invsqrt"

### See Also

FNSetType(), FN

### Level

beginner

### Location

include/slepcfn.h
Index of all FN routines
Table of Contents for all manual pages
Index of all manual pages